@@ -236,7 +236,7 @@ char *argv[];
 	fprintf(makefile, "\t$(CC) -o $@ $(OBJS) $(LIBS)\n");
 #endif
 	fprintf(makefile, "\nclean: \n\trm -f *.o core \n");
-	fprintf(makefile, "\nclobber: clean\n\trm -f splitvt Makefile\n");
+	fprintf(makefile, "\ndistclean: clean\n\trm -f splitvt Makefile\n");
 	fprintf(makefile, "\ninstall: \n\tmv splitvt /usr/local/bin/splitvt\n");
 	fprintf(makefile, "\tmv examples/xsplitvt /usr/local/bin/xsplitvt\n");
 
