@@ -338,9 +338,11 @@ int *source;
 				break;
 		case '=':	/* Set application keypad mode */
 				curwin->key_state=application;
+				vt_keystate(curwin->key_state);
 				break;
 		case '>':	/* Set numeric keypad mode */
 				curwin->key_state=normal;
+				vt_keystate(curwin->key_state);
 				break;
 		case 'N':	/* Select charset G2 for one character */
 				/* UNSUPPORTED */
@@ -674,6 +676,7 @@ int *source;
 			switch (curwin->esc_param[0]) {
 				case 1: /* Cursorkeys in application mode */
 					curwin->key_state=application;
+					vt_keystate(curwin->key_state);
 					break;
 				case 2: /* Set ansi mode */
 					/* UNSUPPORTED */
@@ -716,6 +719,7 @@ int *source;
 			switch (curwin->esc_param[0]) {
 				case 1: /* Cursorkeys in normal mode */
 					curwin->key_state=normal;
+					vt_keystate(curwin->key_state);
 					break;
 				case 2: /* Set VT52 mode */
 					/* UNSUPPORTED */
@@ -858,9 +862,12 @@ char *init_vt100()
 		return("Standard input and output must be a tty");
 
 	/* Initialize the termcap environment */
-	if ( (errmesg=vt_initterm(terminal_type,
+	if ( ! setup_vt100 ) {
+		if ( (errmesg=vt_initterm(terminal_type,
 				&physical.rows, &physical.cols)) != NULL )
-		return(errmesg);
+			return(errmesg);
+		vt_initsel();
+	}
 
 #ifdef TIOCGWINSZ
 	if ( ioctl(0, TIOCGWINSZ, &mywinz) == 0 ) {
@@ -1041,6 +1048,7 @@ char *prompt;
 
 	/* Print out the top separator and go back to where we were */
 	if ( prompt ) {
+		vt_resetattr();
 		vt_reverse(1);
 		printf("\r%s", sep);
 		vt_restcursor();
@@ -1101,6 +1109,7 @@ char *text[];
 	int i;
 
 	vt_clrscr();
+	vt_setscroll(0,0);
 	vt_goto(1,1);
 	vt_bold(1);
 	printf("%s\r\n\r\n", title);
